rsaga.esri.to.sgrd converts grid files from ESRI's ASCII (.asc) and binary (.flt) format to SAGA's (version 2) grid format (.sgrd).
rsaga.esri.to.sgrd(in.grids, out.sgrds = set.file.extension(in.grids, ".sgrd"), in.path, ...).asc); files should be located in folder in.pathin.grids with file extension being replaced by .sgrd, which is also the default extension if file names without extension are specified; files will be placed in the current SAGA workspace (default: rsaga.env()$workspace, or env$workspace if an env argument is providedin.gridsrsaga.geoprocessor, including the env RSAGA geoprocessing environmentintern argument passed to the rsaga.geoprocessor. For intern=FALSE it is a numerical error code (0: success), or otherwise (default) a character vector with the module's console output.If multiple in.grids are converted, the result will be a vector of numerical error codes of the same length, or the combination of the console outputs with c().
rsaga.esri.wrapper for an efficient way of applying RSAGA to ESRI ASCII/binary grids; rsaga.env