rsaga.pisr(in.dem, in.svf.grid = NULL, in.vapour.grid = NULL, in.latitude.grid = NULL, in.longitude.grid = NULL, out.direct.grid, out.diffuse.grid, out.total.grid = NULL, out.ratio.grid = NULL, out.duration, out.sunrise, out.sunset, local.svf = TRUE, latitude, unit = c("kWh/m2", "kJ/m2", "J/cm2"), solconst = 1367, enable.bending = FALSE, bending.radius = 6366737.96, bending.lat.offset = "user", bending.lat.ref.user = 0, bending.lon.offset = "center", bending.lon.ref.user = 0, method = c("height", "components", "lumped"), hgt.atmosphere = 12000, hgt.water.vapour.pressure = 10, cmp.pressure = 1013, cmp.water.content = 1.68, cmp.dust = 100, lmp.transmittance = 70, time.range = c(0, 24), time.step = 0.5, start.date = list(day = 21, month = 3), end.date = NULL, day.step = 5, env = rsaga.env(), ...).sgrd)local.svfhgt.water.vapour.pressurein.latitude.gridunit argument)out.sunriseTRUE; if TRUE, use sky view factor based on local slope (after Oke, 1988), if no sky view factor grid is provided in in.svf.grid"kWh/m2" (default) "kJ/m2", or "J/cm2"FALSE): incorporate effects of planetary bending?6366737.96"user"-defined (default), or relative to "top", "center" or "bottom" of grid?bending.lat.offset"user"-defined, or relative to "top", "center" (default) or "bottom" of grid?"height", or numeric code 0), or air pressure, water and dust content ("components", code 1), or lumped atmospheric transmittance ("lumped", code 0)in.vapour.gridday and month components as numbers; these numbers are one-based (SAGA_CMD uses zero-based numbers internally), i.e. Jan. 1st is list(day=1,month=1)start.datedays indicates a range of days, this specifies the time step (number of days) for calculating the incoming solar radiationrsaga.env; this argument is required for version control (see Note)rsaga.geoprocessormethod = "components" and method = "lumped".
Oke, T.R. (1988): Boundary layer climates. London, Taylor and Francis.
Wilson, J.P., Gallant, J.C. (eds.), 2000: Terrain analysis - principles and applications. New York, John Wiley and Sons.
rsaga.hillshade; for similar modules in older SAGA versions (pre-2.0.6) see rsaga.solar.radiation and rsaga.insolation