rsaga.pisr.
rsaga.pisr2(in.dem, in.svf.grid = NULL, in.vapour.grid = NULL, in.linke.grid = NULL, out.direct.grid, out.diffuse.grid, out.total.grid = NULL, out.ratio.grid = NULL, out.duration, out.sunrise, out.sunset, local.svf = TRUE, location = c("latitude", "grid"), latitude = 53, unit = c("kWh/m2", "kJ/m2", "J/cm2"), solconst = 1367, method = c("height", "components", "lumped", "hofierka"), hgt.atmosphere = 12000, cmp.pressure = 1013, cmp.water.content = 1.68, cmp.dust = 100, lmp.transmittance = 70, time.range = c(0, 24), time.step = 0.5, start.date = list(day = 31, month = 10, year = 2015), end.date = NULL, day.step = 5, env = rsaga.env(), ...).sgrd)local.svfmethod = "height"; default 10 mbarmethod = "hofierka"; default 3.0unit argument)out.sunriseTRUE; if TRUE, use sky view factor based on local slope (after Oke, 1988), if no sky view factor grid is provided in in.svf.gridlatitude below ("latitude" or code 0; default) or as calculated from the grid system ("grid" or code 1)"kWh/m2" (default) "kJ/m2", or "J/cm2""height", or numeric code 0), or air pressure, water and dust content ("components", code 1), or lumped atmospheric transmittance ("lumped", code 2), or by the method of Hofierka and Suri, 2009 ("hofierka", code 3). Default: "lumped".method = "height"method = "components"method = "components"method = "components"day, month, and year components as numbers; month is one-based (SAGA_CMD uses zero-based numbers internally), i.e. Jan. 1st 2015 is list(day=1,month=1,year=2015)start.datedays indicates a range of days, this specifies the time step (number of days) for calculating the incoming solar radiationrsaga.env; this argument is required for version control (see Note)rsaga.geoprocessormethod = "components" and method = "lumped".
Oke, T.R. (1988): Boundary layer climates. London, Taylor and Francis.
Wilson, J.P., Gallant, J.C. (eds.), 2000: Terrain analysis - principles and applications. New York, John Wiley and Sons.
Hofierka, J., Suri, M. (2002): The solar radiation model for Open source GIS: implementation and applications. International GRASS users conference in Trento, Italy, September 2002
rsaga.pisr; for similar modules in older SAGA versions (pre-2.0.6) see rsaga.solar.radiation and rsaga.insolation; rsaga.hillshade