rsaga.sgrd.to.esri converts grid files from SAGA's (version 2) grid format (.sgrd) to ESRI's ASCII (.asc) and binary (.flt) format.
rsaga.sgrd.to.esri(in.sgrds, out.grids, out.path, format = "ascii", georef = "corner", prec = 5, ...).sgrd) to be converted; files are expected to be found in folder rsaga.env()$workspace, or, if an optional env argument is provided, in env$workspacein.sgrds with the file extension being replaced by .asc or .flt, depending on format. Files will be placed in folder out.path, existing files will be overwrittenout.grids"ascii" (default; equivalent: format=1) for ASCII grids or "binary" (equivalent: 0) for binary ESRI grids (.flt)."corner" (equivalent numeric code: 0) or "center" (default; equivalent: 1). Determines whether the georeference will be related to the center or corner of its extreme lower left grid cell.length(in.grids)rsaga.geoprocessor, including the env RSAGA geoprocessing environmentintern argument passed to the rsaga.geoprocessor. For intern=FALSE it is a numerical error code (0: success), or otherwise (default) a character vector with the module's console output.
rsaga.esri.wrapper for an efficient way of applying RSAGA to ESRI ASCII/binary grids; rsaga.env