rsaga.pisr instead with SAGA GIS 2.0.6+.
rsaga.solar.radiation(in.dem, out.grid, out.duration, latitude, unit = c("kWh/m2", "J/m2"), solconst = 1367, method = c("lumped", "components"), transmittance = 70, pressure = 1013, water.content = 1.68, dust = 100, time.range = c(0, 24), time.step = 1, days = list(day = 21, month = 3), day.step = 5, env = rsaga.env(), ...).sgrd)out.grid output: "kWh/m2" (default) or "J/m2"transmittance ("lumped", or numeric code 0; default); or by calculating the components corresponding to water and dust ("components", code 1)day and month specifying a single day of the year for radiation modeling; OR a numeric vector of length 2 specifying the start and end date (see Note below)days indicates a range of days, this specifies the time step (number of days) for calculating the incoming solar radiationrsaga.env; this argument is required for version control (see Note)rsaga.geoprocessorrsaga.hillshade, rsaga.insolation
## Not run:
# # potential solar radiation on Nov 7 in Southern Ontario...
# rsaga.solar.radiation("dem","solrad","soldur",latitude=43,
# days=list(day=7,month=11),time.step=0.5)
# ## End(Not run)
Run the code above in your browser using DataLab